@@ -110,7 +110,7 @@ $MailObject->setDate($mailDate,$LOCALE['dateformat']);
 $MailObject->setTime($mailDate,$LOCALE['timeformat']);
 $MailObject->setBody($body_content,$body_type);
 
-if ($errorMsg) {
+if (isset($errorMsg)) {
     $MailObject->setError('ID_NOT_FOUND');
 }
 $App->response(json_encode($MailObject),'application/json');
